@@ -200,7 +200,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1491"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1539"/>
@@ -210,7 +210,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1542"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Tutup</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1549"/>
@@ -225,7 +225,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="294"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>Versi:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="295"/>
@@ -235,18 +235,18 @@
     <message>
         <location filename="../mainwindow.cpp" line="297"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="298"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation>Lisensi</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="299"/>
         <location filename="../mainwindow.cpp" line="313"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Changelog</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="300"/>
@@ -256,7 +256,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="321"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Tutup</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="340"/>
